//-*-c++-*-

/**
 Author: David Auber
 Email : auber@labri.fr
 Last modification : 20/08/2001
 This program is free software; you can redistribute it and/or modify  *
 it under the terms of the GNU General Public License as published by  
 the Free Software Foundation; either version 2 of the License, or     
 (at your option) any later version.
*/

#ifndef TULIP_STRING_H
#define TULIP_STRING_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "Types.h"
#include "Property.h"

class PropertyContext;
class StringProxy;

/** \addtogroup plugins */ 
/*@{*/

/// Interface for String plug-ins
class TLP_SCOPE String:public Property<StringType , StringType>
{ 
  ///
  friend class StringProxy;
public:
  /** This string proxy is the one associated to the plug-ins,
      The data should be store in it*/
  StringProxy *stringProxy;

protected:
  ///
  String (const PropertyContext &context);
  ///
  virtual ~String(){}
};

/*@}*/
#endif









